Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-08-12 01:35:24 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-08-12 01:35:24 +0400
commitc567cf3fab5b962a4166ef44f45c80941021b60d (patch)
treef3b257cdd6ec3c6241395ca2bb815cc82a428506 /source/blender/windowmanager/intern/wm_operators.c
parentf2d06dc257ec9c4667fd9964243b032fed2d21c3 (diff)
code cleanup: WM naming conventions
Diffstat (limited to 'source/blender/windowmanager/intern/wm_operators.c')
-rw-r--r--source/blender/windowmanager/intern/wm_operators.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/source/blender/windowmanager/intern/wm_operators.c b/source/blender/windowmanager/intern/wm_operators.c
index 52436b6564c..59e0614b18a 100644
--- a/source/blender/windowmanager/intern/wm_operators.c
+++ b/source/blender/windowmanager/intern/wm_operators.c
@@ -326,7 +326,7 @@ static int wm_macro_modal(bContext *C, wmOperator *op, wmEvent *event)
}
}
- WM_cursor_grab(CTX_wm_window(C), wrap, FALSE, bounds);
+ WM_cursor_grab_enable(CTX_wm_window(C), wrap, FALSE, bounds);
}
}
}
@@ -1575,7 +1575,7 @@ static void WM_OT_save_homefile(wmOperatorType *ot)
ot->description = "Make the current file the default .blend file";
ot->invoke = WM_operator_confirm;
- ot->exec = WM_write_homefile;
+ ot->exec = WM_homefile_write_exec;
ot->poll = WM_operator_winactive;
}
@@ -1586,7 +1586,7 @@ static void WM_OT_read_homefile(wmOperatorType *ot)
ot->description = "Open the default file (doesn't save the current file)";
ot->invoke = WM_operator_confirm;
- ot->exec = WM_read_homefile_exec;
+ ot->exec = WM_homefile_read_exec;
/* ommit poll to run in background mode */
}
@@ -1597,7 +1597,7 @@ static void WM_OT_read_factory_settings(wmOperatorType *ot)
ot->description = "Load default file and user preferences";
ot->invoke = WM_operator_confirm;
- ot->exec = WM_read_homefile_exec;
+ ot->exec = WM_homefile_read_exec;
/* ommit poll to run in background mode */
}
@@ -1664,11 +1664,11 @@ static int wm_open_mainfile_exec(bContext *C, wmOperator *op)
else
G.f &= ~G_SCRIPT_AUTOEXEC;
/* XXX wm in context is not set correctly after WM_read_file -> crash */
/* do it before for now, but is this correct with multiple windows? */
WM_event_add_notifier(C, NC_WINDOW, NULL);
- WM_read_file(C, path, op->reports);
+ WM_file_read(C, path, op->reports);
return OPERATOR_FINISHED;
}
@@ -1895,13 +1895,13 @@ static int wm_recover_last_session_exec(bContext *C, wmOperator *op)
G.fileflags |= G_FILE_RECOVER;
/* XXX wm in context is not set correctly after WM_read_file -> crash */
/* do it before for now, but is this correct with multiple windows? */
WM_event_add_notifier(C, NC_WINDOW, NULL);
/* load file */
BLI_make_file_string("/", filename, BLI_temporary_dir(), "quit.blend");
- WM_read_file(C, filename, op->reports);
+ WM_file_read(C, filename, op->reports);
G.fileflags &= ~G_FILE_RECOVER;
return OPERATOR_FINISHED;
@@ -1927,12 +1927,12 @@ static int wm_recover_auto_save_exec(bContext *C, wmOperator *op)
G.fileflags |= G_FILE_RECOVER;
/* XXX wm in context is not set correctly after WM_read_file -> crash */
/* do it before for now, but is this correct with multiple windows? */
WM_event_add_notifier(C, NC_WINDOW, NULL);
/* load file */
- WM_read_file(C, path, op->reports);
+ WM_file_read(C, path, op->reports);
G.fileflags &= ~G_FILE_RECOVER;
@@ -2047,7 +2047,7 @@ static int wm_save_as_mainfile_exec(bContext *C, wmOperator *op)
}
#endif
- if (WM_write_file(C, path, fileflags, op->reports, copy) != 0)
+ if (WM_file_write(C, path, fileflags, op->reports, copy) != 0)
return OPERATOR_CANCELLED;
WM_event_add_notifier(C, NC_WM | ND_FILESAVE, NULL);
@@ -1664,11 +1664,11 @@ static int wm_open_mainfile_exec(bContext *C, wmOperator *op)
else
G.f &= ~G_SCRIPT_AUTOEXEC;
- /* XXX wm in context is not set correctly after WM_read_file -> crash */
+ /* XXX wm in context is not set correctly after WM_file_read -> crash */
/* do it before for now, but is this correct with multiple windows? */
WM_event_add_notifier(C, NC_WINDOW, NULL);
@@ -1895,13 +1895,13 @@ static int wm_recover_last_session_exec(bContext *C, wmOperator *op)
G.fileflags |= G_FILE_RECOVER;
- /* XXX wm in context is not set correctly after WM_read_file -> crash */
+ /* XXX wm in context is not set correctly after WM_file_read -> crash */
/* do it before for now, but is this correct with multiple windows? */
WM_event_add_notifier(C, NC_WINDOW, NULL);
@@ -1927,12 +1927,12 @@ static int wm_recover_auto_save_exec(bContext *C, wmOperator *op)
G.fileflags |= G_FILE_RECOVER;
- /* XXX wm in context is not set correctly after WM_read_file -> crash */
+ /* XXX wm in context is not set correctly after WM_file_read -> crash */
/* do it before for now, but is this correct with multiple windows? */
WM_event_add_notifier(C, NC_WINDOW, NULL);